@@ -186,7 +186,20 @@ class KubernetesVolume(KubernetesBase):
     def get_obj(self):
         return client.V1Volume(
             name=self.slug,
-            empty_dir={}
+            empty_dir=client.V1EmptyDirVolumeSource()
+        )
+
+
+
+class KubernetesVolumeMount(KubernetesBase):
+    mount_path = models.CharField(max_length=255, default="/media")
+    sub_path = models.CharField(max_length=255, default=None, null=True, blank=True)
+
+    def get_obj(self):
+        return client.V1VolumeMount(
+            name=self.slug,
+            mount_path=self.mount_path,
+            sub_path=self.sub_path
         )
 
 
@@ -229,19 +242,6 @@ class KubernetesConfigMap(KubernetesMetadataObjBase):
 
 
 
-class KubernetesVolumeMount(KubernetesBase):
-    mount_path = models.CharField(max_length=255, default="/media")
-    sub_path = models.CharField(max_length=255, default=None, null=True, blank=True)
-
-    def get_obj(self):
-        return client.V1VolumeMount(
-            name=self.slug,
-            mount_path=self.mount_path,
-            sub_path=slef.sub_path
-        )
-
-
-
 class KubernetesContainer(KubernetesBase):
     image_name = models.CharField(max_length=200, db_index=True, help_text="Properly qualified image name to execute this job within", default="debian")
     image_tag = models.CharField(max_length=100, db_index=True, help_text="Tag name for the image to be used for this job", default="latest")
